@@ -1,20 +1,6 @@
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; either version 2 of
-# the License or (at your option) version 3 or any later version
-# accepted by the membership of KDE e.V. (or its successor appro-
-# ved by the membership of KDE e.V.), which shall act as a proxy
-# defined in Section 14 of version 3 of the license.
+# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program. If not, see http://www.gnu.org/licenses/.
-#
-# Copyright (C) 2011 Eike Hein
+# SPDX-FileCopyrightText: 2011 Eike Hein
 
 
 """
@@ -137,12 +123,12 @@ def locale_directories():
 
     """
 
-    dirs = ''
-    
+    dirs = b''
+
     try:
-        dirs = subprocess.check_output(('kde4-config', '--path', 'locale'))
+        dirs = subprocess.check_output(('qtpaths6', '--locate-dirs', 'GenericDataLocation', 'locale'))
     except (OSError, subprocess.CalledProcessError):
-        dbus.error("A problem occured while looking for directories containing translation files. "
+        dbus.error("A problem occurred while looking for directories containing translation files. "
                    "The output of this script will not be translated.")
 
     return dirs.rstrip().decode().split(':')
